--------------------------------------------------------------------------------
-- Company: FSU-FAMU
-- Engineer: YOUR_NAME
-- Create Date:    TODAYS DATE
-- Design Name:    DE2_lab1 
-- Project Name:    lab 1
-- Target Device:   EP2C35F672C6
-- Tool versions:   Quartus II 9.1
-- Description:   This is a sine function generator design (fun_text.vhd) from DSP with FPGAs 
--                   book. DAC, LCD and LEDs are added for debugging and display
--
-- Dependencies: Uses the Audio Codec, IC2 configuration, PLL for 18 MHz
--               the seven segment led0, led1, and Key[0] for reset
--
-- Resources used:
--  Total Number LEs: TBA
--  Number of 9x9 Mults: TBA
--  Bits of M4Ks: TBA
--  Maximum Delay is TBA ns => TBA MHz
--------------------------------------------------------------------------------
library lpm;
USE lpm.lpm_components.ALL;
--------------------------------------------------------------------------------
LIBRARY ieee;
USE ieee.std_logic_1164.ALL;
USE ieee.std_logic_arith.ALL;
USE ieee.std_logic_unsigned.ALL;
--------------------------------------------------------------------------------
ENTITY DE2_lab1 IS
  PORT( clock_50 : IN STD_LOGIC;  --  50 MHz Clock
        clock_18 : BUFFER STD_LOGIC;  --  18 MHz Clock
        key : IN STD_LOGIC_VECTOR(3 DOWNTO 0);  --  Pushbutton[3:0]
        sw : IN STD_LOGIC_VECTOR(17 DOWNTO 0);  --  Toggle Switch[17:0]
        hex0, hex1 : OUT STD_LOGIC_VECTOR(6 DOWNTO 0); --  7-SEG Dispaly
                 -- HEX2, HEX3, HEX4, HEX5, HEX6, HEX7,
        ledg : OUT STD_LOGIC_VECTOR(8 DOWNTO 0);  --  LED Green[8:0]
        ledr : OUT STD_LOGIC_VECTOR(17 DOWNTO 0); --  LED Red[17:0]
------------------------  I2C    --------------------------------
        i2c_sdat : INOUT STD_LOGIC;       --  I2C Data
        i2c_sclk : OUT STD_LOGIC;         --  I2C Clock
--------------------  Audio CODEC    ----------------------------
        aud_adclrck : OUT STD_LOGIC;      --  Audio CODEC ADC LR Clock
        aud_adcdat  : IN STD_LOGIC;       --  Audio CODEC ADC Data
        aud_daclrck : INOUT STD_LOGIC;    --  Audio CODEC DAC LR Clock
        aud_dacdat  : OUT STD_LOGIC;      --  Audio CODEC DAC Data
        aud_bclk    : INOUT STD_LOGIC;    --  Audio CODEC Bit-Stream Clock
        aud_xck     : OUT STD_LOGIC);     --  Audio CODEC Chip Clock
END ENTITY DE2_lab1;

ARCHITECTURE fpga OF DE2_lab1 IS

COMPONENT i2c_config IS  
  PORT (iclk  : IN STD_LOGIC; --  Host side
        irst_n : IN STD_LOGIC;
        i2c_sclk : OUT STD_LOGIC; --  I2C side
        i2c_sdat : INOUT STD_LOGIC);
END COMPONENT;

COMPONENT seg7_lut IS
  PORT(idig : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
       oseg : OUT STD_LOGIC_VECTOR(6 DOWNTO 0));          
END COMPONENT;

COMPONENT audio_pll IS
    PORT(areset : IN STD_LOGIC  := '0';
         inclk0 : IN STD_LOGIC  := '0';
         c0 : OUT STD_LOGIC ;
         locked : OUT STD_LOGIC);
END COMPONENT;

COMPONENT audio_dac IS
  PORT( --  Control Signals incomming
     irst_n : IN STD_LOGIC; -- input reset
     iclk_18_4 : IN STD_LOGIC; -- input 18 MHz clock from PLL
     idata16 : IN STD_LOGIC_VECTOR(15 DOWNTO 0); -- 16 bit data in
     --  Audio Side outgoing
     oaud_data : OUT STD_LOGIC; -- Single output bit stream
     oaud_lrck : OUT STD_LOGIC; -- left =1 /right=0 channel select signal
     oaud_bck : BUFFER STD_LOGIC); -- Bit clock for output
END COMPONENT;

  SIGNAL accu : STD_LOGIC_VECTOR(31 DOWNTO 0);
  SIGNAL daclrck, locked : STD_LOGIC;

-- Sine generator defs
  SIGNAL accu_msbs : STD_LOGIC_VECTOR(7 DOWNTO 0); --  MSBs accu
  SIGNAL dac, lut : STD_LOGIC_VECTOR(15 DOWNTO 0); -- 16 bit register for DAC

begin

  
  ledg(3 DOWNTO 0) <= key;
  ledr <= sw; 
  hex0 <= sw(6 DOWNTO 0);
  


END ARCHITECTURE fpga;
